@@ -1,5 +1,9 @@
 // Targeted scripts can only be invoked by you, the user, eg via a right-click option on the Sites or History tabs
 
+// The following handles differences in printing between Java 7's Rhino JS engine
+// and Java 8's Nashorn JS engine
+if (typeof println == 'undefined') this.println = print;
+
 function invokeWith(msg) {
 	// Debugging can be done using println like this
 	println('Finding comments under ' + msg.getRequestHeader().getURI().toString()); 
@@ -18,11 +22,11 @@ function invokeWith(msg) {
 				body = hr.getHttpMessage().getResponseBody().toString()
 				// Look for html comments
 				if (body.indexOf('<!--') > 0) {
-		           	print(hr.getHttpMessage().getRequestHeader().getURI() + "\n") 
+		           	println(hr.getHttpMessage().getRequestHeader().getURI()) 
 					o = body.indexOf('<!--');
 					while (o > 0) {
 						e = body.indexOf('-->', o);
-			           	print("\t" + body.substr(o,e-o+3) + "\n") 
+			           	println("\t" + body.substr(o,e-o+3)) 
 						o = body.indexOf('<!--', e);
 					}
 				}
